# A Robust and Efficient Method to Find Profile Likelihood Confidence Intervals

This package provides an implementation of a robust and efficient method to
compute profile likelihood confidence intervals (scientific study by 
Fischer and Lewis to be published soon). If you use this package in research 
that leads to a scientific publication, we kindly ask you to cite the 
publication once it is published.

The package is licensed under the [LGPL-v3][LGPL]. For documentation please refer to
[the project's documentation page on github][DOC]. Please report any bugs on 
[the project's bug tracker][BUG]. You are welcome to adjust the provided
files to your needs and to improve the code. It is encouraged that you share any 
improvements on [the github page][GIT] if possible.

[LGPL]: https://opensource.org/licenses/lgpl-3.0.html
[DOC]: https://vemomoto.github.io/ci_rvm.html
[GIT]: https://github.com/vemomoto/vemomoto/
[BUG]: https://github.com/vemomoto/vemomoto/issues